# Inputs

## 1.song_path 
## 2.songwithTime_path 


# Outputs
# timestamp list

# Installation:
## pip install lyric_matcher

## t = lyricsmatcher(../lyrics_only_with_section.txt, ../lyrics_only_with_timestamp.txt)